==> xoonips-3.30.tar.gz: xoonips-3.30/xoonips/detail.php <==
<?php
// $Revision: 1.25.4.5 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

//  page to display item's detail

$xoopsOption['pagetype'] = 'user';
include '../../mainfile.php';
include_once 'condefs.php';
include_once 'include/lib.php';

require_once 'include/create_session.php';
xnp_load_init_create_session();
$xnpsid = $_SESSION['XNPSID'];
$myts   =& MyTextSanitizer::getInstance();

// If not a user, redirect
if ( !$xoopsUser ) {
    if( !xnp_is_valid_session_id($xnpsid) ){
        // User is guest group, and guest isn't admitted to access the page.
        redirect_header(XOOPS_URL.'/index.php',3,_MD_XOONIPS_ITEM_FORBIDDEN);
        exit();
    }
    $uid = UID_GUEST;
}else if( $xoopsUser && !$xoopsUser->isAdmin( $xoopsModule->getVar('mid') )
	&& !xnp_is_activated( $xnpsid, $xoopsUser -> getVar('uid') ) ){
    //̤ǧΥ桼ѤǤʤ(XOOPSԤ)
  	redirect_header('index.php', 3, _MD_XOONIPS_MODERATOR_NOT_ACTIVATED);
  	exit();
}else{
    $uid = $_SESSION['xoopsUserId'];
}

$config_handler =& xoops_gethandler('config');
$xoopsConfigUser =& $config_handler->getConfigsByCat(XOOPS_CONF_USER);

$doi_column_name = XNP_CONFIG_DOI_FIELD_PARAM_NAME;
$param_array = array( 
     'item_id' => 0,
     'index_id' => 0,
     'download_file_id' => false,
     'op' => ''
);
if( $doi_column_name != "" )
    $param_array[ $doi_column_name ] = '';
foreach( $param_array as $k => $v ){
    if( array_key_exists( $k, $_GET ) ){
        $$k = $_GET[$k];
    }else if( array_key_exists( $k, $_POST ) ){
        $$k = $_POST[$k];
    }else{
        $$k = $v;
    }
}

// update $item_id by the ID specified by given doi if exists $$doi_column_name param. 
$doi = "";
if( $doi_column_name != "" && $$doi_column_name != '' ){
    $doi = $$doi_column_name;
    $doi = $myts->stripSlashesGPC( $doi );
    $new_item_ids = array();
    $result = xnpGetItemIdByDoi( $doi, $new_item_ids );
    // error check.
    
    if( count( $new_item_ids ) == 0 ) {
        redirect_header('index.php', 3, _MD_XOONIPS_ITEM_DOI_NOT_FOUND );
        exit();
    } else if( count( $new_item_ids ) > 1 ) {
        redirect_header('index.php', 3, _MD_XOONIPS_ITEM_DOI_DUPLICATE_ID );
        exit();
    }
    $item_id = $new_item_ids[ 0 ];
} 

//retrieve item detail and set item type id to $item_type_id;
$item = array();
$result = xnp_get_item( $xnpsid, $item_id, $item );
if( $result != RES_OK ){
	if( $result == RES_NO_SUCH_ITEM ){
	$_SESSION["back_url"] = $_SERVER["REQUEST_URI"];
	xnpRedirectHeader( 'user.php', 3, _MD_XOONIPS_ITEM_FORBIDDEN );
	//	redirect_header( 'index.php',3,_MD_XOONIPS_ITEM_FORBIDDEN);
	} else {
		redirect_header('index.php', 3, "ERROR xnp_get_item [AbstractLayer]".xnp_get_last_error_string());
	} exit;
}else{
	$item_type_id = $item['item_type_id'];
}

//retrieve module name to $modname
$tmp = array();
$itemtypes = array();
if( xnp_get_item_types( $tmp ) != RES_OK ){
	redirect_header('index.php', 3, "ERROR xnp_get_item_types [AbstractLayer]".xnp_get_last_error_string());
	break;
}else{
    foreach( $tmp as $i ){
        $itemtypes[ $i['item_type_id'] ] = $i;
    }
    
    $itemtype = $itemtypes[ $item_type_id ];
    $modname = $itemtype['name'];
}

if( $op == 'cancel_certify' || $op == 'accept_certify' ){
    //echo "xnp_set_certify_state( $xnpsid, $index_id, $item_id, NOT_CERTIFIED )";
    //$result = xnp_set_certify_state( $xnpsid, $index_id, $item_id, NOT_CERTIFIED );
	$user = array();
	xnp_get_account( $xnpsid, $item['uid'], $user );
    
    $state = NOT_CERTIFIED;
    $body_index = ''; // store index keyword paths
    $myts =& MyTextSanitizer::getInstance();
    foreach( explode( ',', $index_id ) as $xid ){
        if( xnp_get_certify_state( $xnpsid, $xid, $item_id, $state ) == RES_OK ){
            $index = array();
            if( xnp_get_index( $xnpsid, $xid, $index ) == RES_OK ){
                if( $op == 'cancel_certify' ){
                    $result = xnp_unregister_item( $xnpsid, $xid, $item_id );
                    if ( $result == RES_OK )
                        xnp_insert_event( $xnpsid, ETID_REJECT_ITEM, time(), $uid, xnpGetRemoteHost(), array( 'item_id' => $item_id, 'index_id' => $xid ) );
                        // delete record in DB
                        $tab_name = $xoopsDB->prefix('xoonips_item_show');
                        $sql = "DELETE FROM $tab_name WHERE item_id='".$item_id."' ";
                        $res = $xoopsDB->query($sql);
                }else if( $op == 'accept_certify' ){
                    $result = xnp_set_certify_state( $xnpsid, $xid, $item_id, CERTIFIED );
                    if ( $result == RES_OK ){
                        xnp_insert_event( $xnpsid, ETID_CERTIFY_ITEM, time(), $uid, xnpGetRemoteHost(), array( 'item_id' => $item_id, 'index_id' => $xid ) );
                        xnpGenerateRss( ); //update RSS
                    }
                }
                if( $result == RES_OK ){
                    $pathstr = xnpGetIndexPathString( $xnpsid, $xid );
                    $body_index .= $myts->undoHtmlSpecialChars($pathstr)."\n";
                }
            }
        }
    }
    if( $body_index != '' ){
        include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
        eval( "\$metaarray = ".$itemtype['name']."GetMetaInformation( \$item_id );" );
        $body_metadata = "";
        foreach( $metaarray as $k => $v ){ $body_metadata = $body_metadata."$k : $v\n"; }
        global $xoopsModule;
        $tags = array();
        $tags['ITEM_URL'] = xnpGetItemDetailURL( $item_id );
        $tags['INDEX'] = $body_index;
        $tags['METADATA'] = $body_metadata;
        $notification_handler =& xoops_gethandler('notification');
        if( $op == 'cancel_certify' ){
            $result = $notification_handler->triggerEvent('user', 0, 'item_rejected', $tags, array($user['uid']));
        }else if( $op == 'accept_certify' ){
            $result = $notification_handler->triggerEvent('user', 0, 'item_certified', $tags, array($user['uid']));
        }
    }
    
    $op = '';
}

if( $op == 'delete' ){
    include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
    eval( "\$result = ".$modname."DeleteItem( \$item_id );" );
    if( !$result ){
        redirect_header('index.php',3,"ERROR in delete item " );
    }else{
        redirect_header('index.php',3,"Succeed" );
    }
    exit();
}
if( $op == 'print' ){
    require_once XOOPS_ROOT_PATH.'/class/template.php';
    $xoopsTpl = new XoopsTpl();
    xoops_header(false);
    
    // get config of xoonips
    if ( !isset($xoopsConfigMetaFooter) )
        $xoopsConfigMetaFooter =& $config_handler->getConfigsByCat(XOOPS_CONF_METAFOOTER);
    //$xoopsTpl->assign('footer', $xoopsConfigMetaFooter['footer'] );
    $xoopsTpl->assign('meta_copyright', $xoopsConfigMetaFooter['meta_copyright'] );
    $xoopsTpl->assign('meta_author', $xoopsConfigMetaFooter['meta_author'] );
    $xoopsTpl->assign('sitename', $xoopsConfig['sitename'] );
    
    include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
    eval( "\$body = ".$modname."GetPrinterFriendlyDetailBlock( \$item_id );" );
    echo "</head><body onload='window.print();'>\n";
    $val = "";
    xnp_get_config_value( 'printer_friendly_header', $val );
    $xoopsTpl->assign('printer_friendly_header', $val );
    $xoopsTpl->assign('item_url', xnpGetItemDetailURL( $item_id, $doi ) );
    $xoopsTpl->assign('body', $body );
    $xoopsTpl->display( "db:xoonips_detail_print.html" );
    xoops_footer();
    exit();
}

$config_handler =& xoops_gethandler('config');
$xoopsConfigUser =& $config_handler->getConfigsByCat(XOOPS_CONF_USER);
$xoopsOption['template_main'] = 'xoonips_detail.html';
include './header.php';

if( xnp_get_item_permission( $xnpsid, $item_id, OP_DELETE ) && $op != 'print' ){
    $xoopsTpl->assign('delete_button_visible', '1' );
}else{
    $xoopsTpl->assign('delete_button_visible', '0' );
}

// makes Modify button visible if following case
//  - modifying items by moderator is permitted and this page is not for printer friendly.
//  - or, target item is own item($xoopsUser is contributor) and this page is not for printer friendly.
if( ( ( xnp_get_config_value( 'moderator_modify_any_items', $val ) == RES_OK && $val == 'on' && xnp_is_moderator( $xnpsid, $uid ) )
      || xnp_get_item_permission( $xnpsid, $item_id, OP_MODIFY ) )
    && $op != 'print' ){
    $xoopsTpl->assign('modify_button_visible', '1' );
}else{
    $xoopsTpl->assign('modify_button_visible', '0' );
}

if( $op != 'print' ){
    $xoopsTpl->assign('print_button_visible', '1' );
}else{
    $xoopsTpl->assign('print_button_visible', '0' );
}

$xoopsTpl->assign('item_id', $item_id );
if( $doi != "" ){
    $xoopsTpl->assign('doi',      $doi );
    $xoopsTpl->assign('doi_column_name', $doi_column_name );
}

$val = '';
if( xnp_is_moderator( $xnpsid, $uid )
    || xnp_get_config_value( 'export_enabled', $val ) == RES_OK && $val == 'on' ){
    // check this item can edit the index.
    
    // support export ?
    $func_export = $itemtypes[ $item['item_type_id'] ]['name']."ExportItem";
    include_once XOOPS_ROOT_PATH."/modules/".$itemtypes[ $item['item_type_id'] ]['viewphp'];
    if( function_exists( $func_export ) ){
        $xids = array();
        $result = xnp_get_index_id_by_item_id( $xnpsid, $item_id, $xids );
        if ( $result != RES_OK ){
            redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
        }
        foreach( $xids as $index_id ){
            $index = array();
            $result = xnp_get_index( $xnpsid, $index_id, $index );
            if( $result != RES_OK ) continue; // skip index if access forbidden(ex: other's index)
            if( $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $uid ||
                $index['open_level'] == OL_GROUP_ONLY && xnp_is_group_admin( $xnpsid, $index['owner_gid'], $uid ) ||
                $index['open_level'] == OL_PUBLIC && xnp_is_moderator( $xnpsid, $uid ) && $index['item_id'] != IID_BINDERS && $index['item_id'] != IID_ROOT ){
                $xoopsTpl->assign('export_enabled', 1 );
                break;
            }
        }
    }
}

function genSelectLabels( &$index ){
    $title = $index['titles'][DEFAULT_INDEX_TITLE_OFFSET];
    $indent_html = str_repeat( '&nbsp;&nbsp;', (int)($index['depth']));
    if ( isset( $index['child_count'] ) &&  $index['child_count'] != 0 )
        $childCount = '( ' . $index['child_count'] . ' )';
    else
        $childCount = '';
    $index['indent_html'] = $indent_html;
    $index['select_label'] = " $title $childCount";
}

// display of 'add to public'
if ( $op == '' ){
    // Display only 'Binder -> Binders'. Display 'Not Binder -> Public not Binders'.
    include_once 'include/gentree.php';
    $index = array( 'open_level' => OL_PUBLIC );
    $indexTree = genSameAreaIndexTree( $xnpsid, $uid, $index );
    $len = count( $indexTree );
    for ( $i = 0; $i < $len; $i++ ){
        if ( $item_type_id == ITID_BINDER && $indexTree[$i]['item_id'] != IID_BINDERS 
          || $item_type_id != ITID_BINDER && $indexTree[$i]['item_id'] == IID_BINDERS  )
            unset( $indexTree[$i] );
    }
    array_walk( $indexTree, 'genSelectLabels' );
    $xoopsTpl->assign( 'index_tree', $indexTree );
}

include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
eval( "\$body = ".$modname."GetDetailBlock( \$item_id );" );
$xoopsTpl->assign('body', $body );

$download_file_id = ($op == 'download' ? (int)$download_file_id : false);

$func = $modname."GetDownloadConfirmationBlock";
if ( function_exists( $func ) )
	$xoopsTpl->assign('download_confirmation', $func($item_id, $download_file_id ) );
else
	$xoopsTpl->assign('download_file_id', $download_file_id );

$xoonips_module_header = '<link rel="stylesheet" type="text/css" href="style.css" />';
$xoonips_module_header .= $xoopsTpl->get_template_vars('xoops_module_header');
$xoopsTpl->assign('xoops_module_header', $xoonips_module_header );

// Record events(view item)
xnp_insert_event( $xnpsid, ETID_VIEW_ITEM, time(), $uid, xnpGetRemoteHost(), array( 'item_id' => $item_id ) );
$basic=xnpGetBasicInformationArray($item_id);
$xoopsTpl->assign('xoops_pagetitle', $myts->htmlSpecialChars( $basic['titles'][0] ) );
include XOOPS_ROOT_PATH.'/footer.php';
?>

==> xoonips-3.32.tar.gz: xoonips-3.32/xoonips/detail.php <==
<?php
// $Revision: 1.25.4.8 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

//  page to display item's detail

$xoopsOption['pagetype'] = 'user';
include '../../mainfile.php';
include_once 'condefs.php';
include_once 'include/lib.php';

require_once 'include/create_session.php';
xnp_load_init_create_session();
$xnpsid = $_SESSION['XNPSID'];
$myts   =& MyTextSanitizer::getInstance();

// If not a user, redirect
if ( !$xoopsUser ) {
    if( !xnp_is_valid_session_id($xnpsid) ){
        // User is guest group, and guest isn't admitted to access the page.
        redirect_header('user.php',3,_MD_XOONIPS_ITEM_FORBIDDEN);
        exit();
    }
    $uid = UID_GUEST;
}else if( $xoopsUser && !$xoopsUser->isAdmin( $xoopsModule->getVar('mid') )
	&& !xnp_is_activated( $xnpsid, $xoopsUser -> getVar('uid') ) ){
        // disable to access by not certified user without xoonips admin
  	redirect_header( XOOPS_URL.'/', 3, _MD_XOONIPS_MODERATOR_NOT_ACTIVATED);
  	exit();
}else{
    $uid = $_SESSION['xoopsUserId'];
}

$config_handler =& xoops_gethandler('config');
$xoopsConfigUser =& $config_handler->getConfigsByCat(XOOPS_CONF_USER);

$doi_column_name = XNP_CONFIG_DOI_FIELD_PARAM_NAME;
$param_array = array( 
     'item_id' => 0,
     'index_id' => 0,
     'download_file_id' => false,
     'op' => ''
);
if( $doi_column_name != "" )
    $param_array[ $doi_column_name ] = '';
foreach( $param_array as $k => $v ){
    if( array_key_exists( $k, $_GET ) ){
        $$k = $_GET[$k];
    }else if( array_key_exists( $k, $_POST ) ){
        $$k = $_POST[$k];
    }else{
        $$k = $v;
    }
}

// update $item_id by the ID specified by given doi if exists $$doi_column_name param. 
$doi = "";
if( $doi_column_name != "" && $$doi_column_name != '' ){
    $doi = $$doi_column_name;
    $doi = $myts->stripSlashesGPC( $doi );
    $new_item_ids = array();
    $result = xnpGetItemIdByDoi( $doi, $new_item_ids );
    // error check.
    
    if( count( $new_item_ids ) == 0 ) {
        redirect_header( XOOPS_URL.'/', 3, _MD_XOONIPS_ITEM_DOI_NOT_FOUND );
        exit();
    } else if( count( $new_item_ids ) > 1 ) {
        redirect_header( XOOPS_URL.'/', 3, _MD_XOONIPS_ITEM_DOI_DUPLICATE_ID );
        exit();
    }
    $item_id = $new_item_ids[ 0 ];
} 

//retrieve item detail and set item type id to $item_type_id;
$item = array();
$result = xnp_get_item( $xnpsid, $item_id, $item );
if( $result != RES_OK ){
    if( $result == RES_NO_SUCH_ITEM ){
        redirect_header( 'user.php', 3, _MD_XOONIPS_ITEM_FORBIDDEN );
    } else {
        redirect_header( XOOPS_URL.'/', 3, "ERROR xnp_get_item [AbstractLayer]".xnp_get_last_error_string());
    }
    exit();
}else{
	$item_type_id = $item['item_type_id'];
}

//retrieve module name to $modname
$tmp = array();
$itemtypes = array();
if( xnp_get_item_types( $tmp ) != RES_OK ){
	redirect_header( XOOPS_URL.'/', 3, "ERROR xnp_get_item_types [AbstractLayer]".xnp_get_last_error_string());
	break;
}else{
    foreach( $tmp as $i ){
        $itemtypes[ $i['item_type_id'] ] = $i;
    }
    
    $itemtype = $itemtypes[ $item_type_id ];
    $modname = $itemtype['name'];
}

if( $op == 'cancel_certify' || $op == 'accept_certify' ){
    //echo "xnp_set_certify_state( $xnpsid, $index_id, $item_id, NOT_CERTIFIED )";
    //$result = xnp_set_certify_state( $xnpsid, $index_id, $item_id, NOT_CERTIFIED );
	$user = array();
	xnp_get_account( $xnpsid, $item['uid'], $user );
    
    $state = NOT_CERTIFIED;
    $body_index = ''; // store index keyword paths
    $myts =& MyTextSanitizer::getInstance();
    foreach( explode( ',', $index_id ) as $xid ){
        if( xnp_get_certify_state( $xnpsid, $xid, $item_id, $state ) == RES_OK ){
            $index = array();
            if( xnp_get_index( $xnpsid, $xid, $index ) == RES_OK ){
                if( $op == 'cancel_certify' ){
                    $result = xnp_unregister_item( $xnpsid, $xid, $item_id );
                    if ( $result == RES_OK )
                        xnp_insert_event( $xnpsid, ETID_REJECT_ITEM, time(), $uid, xnpGetRemoteHost(), array( 'item_id' => $item_id, 'index_id' => $xid ) );
                        // delete record in DB
                        $tab_name = $xoopsDB->prefix('xoonips_item_show');
                        $sql = "DELETE FROM $tab_name WHERE item_id='".$item_id."' ";
                        $res = $xoopsDB->query($sql);
                }else if( $op == 'accept_certify' ){
                    $result = xnp_set_certify_state( $xnpsid, $xid, $item_id, CERTIFIED );
                    if ( $result == RES_OK ){
                        xnp_insert_event( $xnpsid, ETID_CERTIFY_ITEM, time(), $uid, xnpGetRemoteHost(), array( 'item_id' => $item_id, 'index_id' => $xid ) );
                        xnpGenerateRss( ); //update RSS
                    }
                }
                if( $result == RES_OK ){
                    $pathstr = xnpGetIndexPathString( $xnpsid, $xid );
                    $body_index .= $myts->undoHtmlSpecialChars($pathstr)."\n";
                }
            }
        }
    }
    if( $body_index != '' ){
        include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
        eval( "\$metaarray = ".$itemtype['name']."GetMetaInformation( \$item_id );" );
        $body_metadata = "";
        foreach( $metaarray as $k => $v ){ $body_metadata = $body_metadata."$k : $v\n"; }
        global $xoopsModule;
        $tags = array();
        $tags['ITEM_URL'] = xnpGetItemDetailURL( $item_id );
        $tags['INDEX'] = $body_index;
        $tags['METADATA'] = $body_metadata;
        $notification_handler =& xoops_gethandler('notification');
        if( $op == 'cancel_certify' ){
            $result = $notification_handler->triggerEvent('user', 0, 'item_rejected', $tags, array($user['uid']));
        }else if( $op == 'accept_certify' ){
            $result = $notification_handler->triggerEvent('user', 0, 'item_certified', $tags, array($user['uid']));
        }
    }
    
    $op = '';
}

if( $op == 'delete' ){
    include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
    eval( "\$result = ".$modname."DeleteItem( \$item_id );" );
    if( !$result ){
        redirect_header(XOOPS_URL.'/',3,"ERROR in delete item " );
    }else{
        redirect_header(XOOPS_URL.'/',3,"Succeed" );
    }
    exit();
}
if( $op == 'print' ){
    require_once XOOPS_ROOT_PATH.'/class/template.php';
    $xoopsTpl = new XoopsTpl();
    xoops_header(false);
    
    // get config of xoonips
    if ( !isset($xoopsConfigMetaFooter) )
        $xoopsConfigMetaFooter =& $config_handler->getConfigsByCat(XOOPS_CONF_METAFOOTER);
    //$xoopsTpl->assign('footer', $xoopsConfigMetaFooter['footer'] );
    $xoopsTpl->assign('meta_copyright', $xoopsConfigMetaFooter['meta_copyright'] );
    $xoopsTpl->assign('meta_author', $xoopsConfigMetaFooter['meta_author'] );
    $xoopsTpl->assign('sitename', $xoopsConfig['sitename'] );
    
    include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
    eval( "\$body = ".$modname."GetPrinterFriendlyDetailBlock( \$item_id );" );
    echo "</head><body onload='window.print();'>\n";
    $val = "";
    xnp_get_config_value( 'printer_friendly_header', $val );
    $xoopsTpl->assign('printer_friendly_header', $val );
    $xoopsTpl->assign('item_url', xnpGetItemDetailURL( $item_id, $doi ) );
    $xoopsTpl->assign('body', $body );
    $xoopsTpl->display( "db:xoonips_detail_print.html" );
    xoops_footer();
    exit();
}

$config_handler =& xoops_gethandler('config');
$xoopsConfigUser =& $config_handler->getConfigsByCat(XOOPS_CONF_USER);
$xoopsOption['template_main'] = 'xoonips_detail.html';
include './header.php';

if( xnp_get_item_permission( $xnpsid, $item_id, OP_DELETE ) && $op != 'print' ){
    $xoopsTpl->assign('delete_button_visible', '1' );
}else{
    $xoopsTpl->assign('delete_button_visible', '0' );
}

// makes Modify button visible if following case
//  - modifying items by moderator is permitted and this page is not for printer friendly.
//  - or, target item is own item($xoopsUser is contributor) and this page is not for printer friendly.
if( ( ( xnp_get_config_value( 'moderator_modify_any_items', $val ) == RES_OK && $val == 'on' && xnp_is_moderator( $xnpsid, $uid ) )
      || xnp_get_item_permission( $xnpsid, $item_id, OP_MODIFY ) )
    && $op != 'print' ){
    $xoopsTpl->assign('modify_button_visible', '1' );
}else{
    $xoopsTpl->assign('modify_button_visible', '0' );
}

if( $op != 'print' ){
    $xoopsTpl->assign('print_button_visible', '1' );
}else{
    $xoopsTpl->assign('print_button_visible', '0' );
}

$xoopsTpl->assign('item_id', $item_id );
if( $doi != "" ){
    $xoopsTpl->assign('doi',      $doi );
    $xoopsTpl->assign('doi_column_name', $doi_column_name );
}

$val = '';
if( xnp_is_moderator( $xnpsid, $uid )
    || xnp_get_config_value( 'export_enabled', $val ) == RES_OK && $val == 'on' ){
    // check this item can edit the index.
    
    // support export ?
    $func_export = $itemtypes[ $item['item_type_id'] ]['name']."ExportItem";
    include_once XOOPS_ROOT_PATH."/modules/".$itemtypes[ $item['item_type_id'] ]['viewphp'];
    if( function_exists( $func_export ) ){
        $xids = array();
        $result = xnp_get_index_id_by_item_id( $xnpsid, $item_id, $xids );
        if ( $result != RES_OK ){
            redirect_header(XOOPS_URL.'/',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
        }
        foreach( $xids as $index_id ){
            $index = array();
            $result = xnp_get_index( $xnpsid, $index_id, $index );
            if( $result != RES_OK ) continue; // skip index if access forbidden(ex: other's index)
            if( $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $uid ||
                $index['open_level'] == OL_GROUP_ONLY && xnp_is_group_admin( $xnpsid, $index['owner_gid'], $uid ) ||
                $index['open_level'] == OL_PUBLIC && xnp_is_moderator( $xnpsid, $uid ) && $index['item_id'] != IID_BINDERS && $index['item_id'] != IID_ROOT ){
                $xoopsTpl->assign('export_enabled', 1 );
                break;
            }
        }
    }
}

function genSelectLabels( &$index ){
    $title = $index['titles'][DEFAULT_INDEX_TITLE_OFFSET];
    $indent_html = str_repeat( '&nbsp;&nbsp;', (int)($index['depth']));
    if ( isset( $index['child_count'] ) &&  $index['child_count'] != 0 )
        $childCount = '( ' . $index['child_count'] . ' )';
    else
        $childCount = '';
    $index['indent_html'] = $indent_html;
    $index['select_label'] = " $title $childCount";
}

// display of 'add to public'
if ( $op == '' ){
    // Display only 'Binder -> Binders'. Display 'Not Binder -> Public not Binders'.
    include_once 'include/gentree.php';
    $index = array( 'open_level' => OL_PUBLIC );
    $indexTree = genSameAreaIndexTree( $xnpsid, $uid, $index );
    $len = count( $indexTree );
    for ( $i = 0; $i < $len; $i++ ){
        if ( $item_type_id == ITID_BINDER && $indexTree[$i]['item_id'] != IID_BINDERS 
          || $item_type_id != ITID_BINDER && $indexTree[$i]['item_id'] == IID_BINDERS  )
            unset( $indexTree[$i] );
    }
    array_walk( $indexTree, 'genSelectLabels' );
    $xoopsTpl->assign( 'index_tree', $indexTree );
}

include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
eval( "\$body = ".$modname."GetDetailBlock( \$item_id );" );
$xoopsTpl->assign('body', $body );

$download_file_id = ($op == 'download' ? (int)$download_file_id : false);

$func = $modname."GetDownloadConfirmationBlock";
if ( function_exists( $func ) )
	$xoopsTpl->assign('download_confirmation', $func($item_id, $download_file_id ) );
else
	$xoopsTpl->assign('download_file_id', $download_file_id );

$xoonips_module_header = '<link rel="stylesheet" type="text/css" href="style.css" />';
$xoonips_module_header .= $xoopsTpl->get_template_vars('xoops_module_header');
$xoopsTpl->assign('xoops_module_header', $xoonips_module_header );

// Record events(view item)
xnp_insert_event( $xnpsid, ETID_VIEW_ITEM, time(), $uid, xnpGetRemoteHost(), array( 'item_id' => $item_id ) );
$basic=xnpGetBasicInformationArray($item_id);
$xoopsTpl->assign('xoops_pagetitle', $myts->htmlSpecialChars( $basic['titles'][0] ) );
include XOOPS_ROOT_PATH.'/footer.php';
?>
